# mcmng

Command line based [minecraft](https://www.minecraft.net/en-us) server manager for individual admins.

## Installation

- Install [python 3.10](https://www.python.org/downloads/) or higher
- `pip install mcmng`

## Development

- Install [python 3.10](https://www.python.org/downloads/) or higher
- Install [poetry](https://python-poetry.org/)
- `poetry install`
